/*
 * @file tlc1570.h
 *
 * @brief TLC1570 Descriptor
 *
 * @copyright Copyright (C) 2023 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef TLC1570_H_
#define TLC1570_H_

#include <stdint.h>


/* configuration register (CR) definition
 * |------------------------------------------------------------------------------------------------
 * |   Bit 15  |   Bit 14  |   Bit 13  |   Bit 12  |   Bit 11  |   Bit 10  |   Bit 9   |   Bit 8   |
 * |------------------------------------------------------------------------------------------------
 * |    PWDN   |    READ   |       INPUT[1:0]      |   SPEED   |  AUTOSCAN |        MUX[2:1]        
 * |------------------------------------------------------------------------------------------------
 * ------------------------------------------------------------------------------------------------|
 * |   Bit 7   |   Bit 6   |   Bit 5   |   Bit 4   |   Bit 3   |   Bit 2   |   Bit 1   |   Bit 0   |
 * ------------------------------------------------------------------------------------------------|
 *     MUX[0]  |   REFSRC  |   REFVAL  |  AUTOPWDN |    AVDD   |           RESERVED[2:0]           |
 * ------------------------------------------------------------------------------------------------|
 */

    /* PWDN field */
    #define CR_PWDN_EN											((uint16_t) 0x8000)

    /* READ field */
    #define CR_READ_EN											((uint16_t) 0x4000)

    /* INPUT field */
    #define CR_INPUT_AIN										((uint16_t) 0x0000)    // DEFAULT
    #define CR_INPUT_AGND										((uint16_t) 0x1000)
    #define CR_INPUT_MIDREF									    ((uint16_t) 0x2000)

    /* SPEED field */
    #define CR_SPEED_HIGH										((uint16_t) 0x0000)    // DEFAULT
    #define CR_SPEED_LOW										((uint16_t) 0x0800)

    /* AUTOSCAN1 field */
    #define CR_AUTOSCAN_DIS			    						((uint16_t) 0x0000)    // DEFAULT
    #define CR_AUTOSCAN_EN										((uint16_t) 0x0400)

    /* MUX field (Fixed-channel mode) */
    #define CR_MUX_CH0											((uint16_t) 0x0000)    // DEFAULT
    #define CR_MUX_CH1											((uint16_t) 0x0080)
    #define CR_MUX_CH2											((uint16_t) 0x0100)
    #define CR_MUX_CH3											((uint16_t) 0x0180)
    #define CR_MUX_CH4											((uint16_t) 0x0200)
    #define CR_MUX_CH5											((uint16_t) 0x0280)
    #define CR_MUX_CH6											((uint16_t) 0x0300)
    #define CR_MUX_CH7											((uint16_t) 0x0380)

    /* MUX field (Autoscan mode) */
    #define CR_AUTO_ALL											((uint16_t) 0x0000)    // DEFAULT
    #define CR_AUTO_ODD											((uint16_t) 0x0100)
    #define CR_AUTO_EVEN										((uint16_t) 0x0200)
    #define CR_AUTO_REVERSE										((uint16_t) 0x0300)
    #define CR_AUTO_RESET									    ((uint16_t) 0x0080)

    /* REFSRC field */
    #define CR_REFSRC_EXT										((uint16_t) 0x0000)    // DEFAULT
    #define CR_REFSRC_INT										((uint16_t) 0x0040)

    /* REFVAL field */
    #define CR_REFVAL_2_3V										((uint16_t) 0x0000)    // DEFAULT
    #define CR_REFVAL_3_8V										((uint16_t) 0x0020)

    /* AUTOPWDN field */
    #define CR_AUTOPWDN_EN										((uint16_t) 0x0010)

    /* AVDD field */
    #define CR_AVDD_5_5V_TO_3_6V								((uint16_t) 0x0000)    // DEFAULT
    #define CR_AVDD_3_5V_TO_2_7V								((uint16_t) 0x0008)


#endif /* TLC1570_H_ */
